//	Copyright  1995 Apple Computer, Inc. All rights reserved.
//	Release Version:	$ 1.0 d11 $

//================================================================================
#ifndef DATAPRT_H
#include "DataPrt.h"		// CDataPart
#endif

#ifndef _DATAFRAME_
#include "DataFrm.h"		// CDataFrame
#endif

#ifndef PIZZA_H
#include "Pizza.h"			//  CPizza
#endif

// ----- Framework Layer -----
#ifndef FWPRESEN_H
#include "FWPresen.h"		// FW_CPresentation
#endif

#ifndef FWUTIL_H
#include "FWUtil.h"			// FW_Beep()
#endif

#ifndef FWMEMMGR_H
#include "FWMemMgr.h"		// FW_CMemoryManager
#endif

//==============================================================================
const ODValueType CDataPart::kPartKind = kDataKind;
const ODValueType CDataPart::kPartUserName = kDataEditorUserString;

#define kMainPresentation	"Apple:Presentation:Data"

#ifdef FW_BUILD_MAC
#pragma segment Data
#endif

//==============================================================================
CDataPart::CDataPart(ODPart* odPart)
  :	FW_CPart(odPart, kPartKind, kPartUserName, FW_gInstance, kPartIconID),
	fNumPizzas(0),
	fStringPtr(NULL),
	fBufferPtr(NULL),
	fBufferBytes(0),
	fPresentation(NULL),
	fPizzaList(NULL)
{
}

//--------------------------------------------------------------------------------
CDataPart::~CDataPart()
{
	delete fStringPtr;
	FW_CMemoryManager::FreeBlock(fBufferPtr);
	CPizza* pizza = NULL;
	while ((pizza = (CPizza*)fPizzaList->First()) != NULL) {
		fPizzaList->Remove(pizza);
		delete pizza;
		}
	delete fPizzaList;
}

//--------------------------------------------------------------------------------
void 
CDataPart::Initialize(Environment* ev)	// Override
{
	FW_CPart::Initialize(ev);
	fPresentation = this->RegisterPresentation(ev, kMainPresentation, TRUE, NULL);
	// init strings
	fEmbeddedString.ReplaceAll("Embedded string");
	fStringPtr = FW_NEW(FW_CString32, ("String Pointer") );

	// init buffer
	fBufferBytes = 1000;
	fBufferPtr = FW_CMemoryManager::AllocateBlock(fBufferBytes);	

	fPizzaList = new FW_CPrivOrderedCollection;
}

//--------------------------------------------------------------------------------
FW_CFrame* 
CDataPart::NewFrame(Environment* ev, ODFrame* odFrame,
						FW_CPresentation* presentation, FW_Boolean fromStorage)	// Override
{
	FW_UNUSED(presentation);
	FW_UNUSED(fromStorage);
	return new CDataFrame(ev, odFrame, presentation, this);
}

//--------------------------------------------------------------------------------
void 
CDataPart::MyInvalidatePresentation(Environment* ev)
{
	fPresentation->Invalidate(ev);
}

//--------------------------------------------------------------------------------
void 
CDataPart::MyIncrement()
{
	fNumPizzas++;
	FW_CRect bounds(FW_IntToFixed(0), FW_IntToFixed(0), FW_IntToFixed(30), FW_IntToFixed(30));
	FW_CPoint pt(FW_IntToFixed(fNumPizzas * 15), FW_IntToFixed(fNumPizzas * 15) );
	bounds.Offset(pt);
	CPizza* pizza = new CPizza(bounds);
	fPizzaList->AddLast(pizza);
}

//--------------------------------------------------------------------------------
FW_CPrivOrderedCollection* 
CDataPart::MyGetPizzaList()
{
	return fPizzaList;
}
